@@ -331,7 +331,6 @@ void labeltext(int keypressed, char *clientdata)
    }
    else if (isbound(keypressed, XCF_Text_Return)) {
       Boolean hasstuff = False;   /* Check for null string */
-      Boolean do_all = True;
       stringpart *tmppos;
 
       for (tmppos = curlabel->string; tmppos != NULL; tmppos = tmppos->nextpart) {
@@ -346,7 +345,7 @@ void labeltext(int keypressed, char *clientdata)
 	 topobject->parts++;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-         topobject->valid = False;
+	 invalidate_netlist(topobject);
 #endif
 
       }
@@ -400,7 +399,7 @@ void labeltext(int keypressed, char *clientdata)
 	 eventmode = NORMAL_MODE;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-	 if (curlabel->pin != False) topobject->valid = False;
+	 if (curlabel->pin != False) invalidate_netlist(topobject);
 #endif
       }
 
@@ -419,12 +418,12 @@ void labeltext(int keypressed, char *clientdata)
 	    if ((findlabelcopy(curlabel, labelbuf) == NULL)
 			&& (findlabelcopy(curlabel, curlabel->string) == NULL)) {
 	       changeotherpins(curlabel, labelbuf);
-	       if (topobject->schemtype == SCHEMATIC)
+	       if (topobject->schemtype == PRIMARY || topobject->schemtype == SECONDARY)
 	          Wprintf("Changed corresponding pin in associated symbol");
 	       else
 	          Wprintf("Changed corresponding pin in associated schematic");
 	       incr_changes(topobject->symschem);
-	       topobject->symschem->valid = False;
+	       invalidate_netlist(topobject->symschem);
 	    }
 	 }
 #endif
@@ -432,10 +431,7 @@ void labeltext(int keypressed, char *clientdata)
 	 freelabel(labelbuf);
 	 labelbuf = NULL;
 	 resolveparams(areastruct.topinstance);
-	 if (do_all >= 0)
-            updateinstparam(areastruct.topinstance, do_all);
-	 else /* do_all == -1 */
-	    calcbbox(areastruct.topinstance);
+         updateinstparam(areastruct.topinstance);
 #ifdef SCHEMA
 	 setobjecttype(topobject);
 #endif
@@ -1665,6 +1661,21 @@ void join()
    free(direc);
 }
 
+/*----------------------------------------------*/
+/* Add a new point to a polygon			*/
+/*----------------------------------------------*/
+
+void poly_add_point(polyptr thispoly, XPoint *newpoint) {
+   XPoint *tpoint;
+
+   thispoly->number++;
+   thispoly->points = (XPoint *)realloc(thispoly->points,
+			thispoly->number * sizeof(XPoint));
+   tpoint = thispoly->points + thispoly->number - 1;
+   tpoint->x = newpoint->x;
+   tpoint->y = newpoint->y;
+}
+
 /*-------------------------------------------------*/
 /* ButtonPress handler while a wire is being drawn */
 /*-------------------------------------------------*/
@@ -1703,12 +1714,9 @@ void wirebutton(XButtonEvent *event)
    }
 
    if (newwire && event->button == Button1) {
-      if (++newwire->number == 3) newwire->style = areastruct.style;
-      newwire->points = (XPoint *)realloc(newwire->points, newwire->number
-		* sizeof(XPoint));
-      tpoint = newwire->points + newwire->number - 1;
-      tpoint->x = userpt.x;
-      tpoint->y = userpt.y;
+      if (newwire->number == 2)
+	 newwire->style = areastruct.style;
+      poly_add_point(newwire, &userpt);
    }
    else if (newwire == NULL || event->button != Button3)
       xcRemoveEventHandler(areastruct.area, PointerMotionMask, False,
@@ -1721,7 +1729,7 @@ void wirebutton(XButtonEvent *event)
 	 topobject->parts++;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-	 if (!nonnetwork(newwire)) topobject->valid = False;
+	 if (!nonnetwork(newwire)) invalidate_netlist(topobject);
 #endif
       }
       UDrawPolygon(newwire);
