@@ -1130,68 +1130,37 @@ void calcbboxinst(objinstptr thisinst)
 /* takes the default value.					*/
 /*--------------------------------------------------------------*/
 
-void updateinstparam(objectptr bobj, int mode)
+void updateinstparam(objectptr bobj)
 {
    short i, j;
    objectptr pageobj;
 
-   /* this is a modified version of updatepagebounds() 	*/
-   /* mode == 0:  change bounds on pagelib and the page	*/
-   /* containing this object *instance*			*/
+   /* change bounds on pagelib and all pages			*/
+   /* containing this *object* if and only if the object	*/
+   /* instance takes the default value.  Also update the	*/
+   /* library page.						*/
 
-   if (mode == 0) {
-      /* pick up calling object and instance from the edit stack */
-      objinstptr pinst = areastruct.stack->thisinst;
+   for (i = 0; i < xobjs.pages; i++)
+      if (xobjs.pagelist[i]->pageinst != NULL) {
+	 pageobj = xobjs.pagelist[i]->pageinst->thisobject;
+         if ((j = find_object(pageobj, topobject)) >= 0) {
 
-      pageobj = pinst->thisobject;
+	    /* Really, we'd like to recalculate the bounding box only if the */
+	    /* parameter value is the default value which was just changed.	*/
+	    /* However, then any non-default values may contain the wrong	*/
+	    /* substitutions.						*/
 
-      for (j = 0; j < pageobj->parts; j++)
-	 if (*(pageobj->plist + j) == (genericptr)pinst) break;
-      if (j == pageobj->parts) {
-	 Fprintf(stderr, "Error: Calling page does not contain expected objinst!\n");
-	 return;
-      }
-      calcbboxvalues(pinst, (genericptr *)(pageobj->plist + j));
-      for (i = 0; i < xobjs.pages; i++) {
-	 if (xobjs.pagelist[i]->pageinst != NULL) {
-	    if (xobjs.pagelist[i]->pageinst->thisobject == pageobj) {
-               updatepagelib(PAGELIB, i);
-	       break;
+	    objinstptr cinst = TOOBJINST(pageobj->plist + j);
+	    if (cinst->thisobject->params == NULL) {
+	       calcbboxvalues(xobjs.pagelist[i]->pageinst, pageobj->plist + j);
+	       updatepagelib(PAGELIB, i);
 	    }
 	 }
       }
-      if (i == xobjs.pages)
-	 Fprintf(stderr, "Error: Calling page not found!\n");
-   }
 
-   /* mode == 1:  change bounds on pagelib and all pages	*/
-   /*   containing this *object* if and only if the object	*/
-   /*   instance takes the default value.  Also update the	*/
-   /*   library page.						*/
-
-   else {
-      for (i = 0; i < xobjs.pages; i++)
-         if (xobjs.pagelist[i]->pageinst != NULL) {
-	    pageobj = xobjs.pagelist[i]->pageinst->thisobject;
-            if ((j = find_object(pageobj, topobject)) >= 0) {
-
-	       /* Really, we'd like to recalculate the bounding box only if the */
-	       /* parameter value is the default value which was just changed.	*/
-	       /* However, then any non-default values may contain the wrong	*/
-	       /* substitutions.						*/
-
-	       objinstptr cinst = TOOBJINST(pageobj->plist + j);
-	       if (cinst->thisobject->params == NULL) {
-	          calcbboxvalues(xobjs.pagelist[i]->pageinst, pageobj->plist + j);
-	          updatepagelib(PAGELIB, i);
-	       }
-	    }
-	 }
-
-      for (i = 0; i < xobjs.numlibs; i++)
-         if (object_in_library(i, topobject))
-	    composelib(i + LIBRARY);
-   }
+   for (i = 0; i < xobjs.numlibs; i++)
+      if (object_in_library(i, topobject))
+	 composelib(i + LIBRARY);
 }
 
 /*--------------------------------------------------------------*/
