@@ -67,11 +67,11 @@ extern short help_up;
 static char *function_names[NUM_FUNCTIONS + 1] = {
    "Page", "Justify", "Superscript", "Subscript", "Normalscript",
    "Nextfont", "Boldfont", "Italicfont", "Normalfont", "Underline",
-   "Overline", "ISO Encoding", "Return", "Halfspace", "Quarterspace",
+   "Overline", "ISO Encoding", "Halfspace", "Quarterspace",
    "Special", "Tab Stop", "Tab Forward", "Tab Backward",
    "Text Return", "Text Delete", "Text Right", "Text Left",
    "Text Up", "Text Down", "Text Split", 
-   "Text Home", "Text End", "Return Char", "Parameter",
+   "Text Home", "Text End", "Linebreak", "Parameter",
    "Parameterize Point", "Break at Point", "Delete Point", "Insert Point",
    "Append Point", "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
@@ -558,7 +558,7 @@ void default_keybindings()
    add_binding(ALT | XK_u, XCF_Underline);
    add_binding(ALT | XK_o, XCF_Overline);
    add_binding(ALT | XK_e, XCF_ISO_Encoding);
-   add_binding(ALT | XK_Return, XCF_Return_Char);
+   add_binding(ALT | XK_Return, XCF_Linebreak);
    add_binding(ALT | XK_h, XCF_Halfspace);
    add_binding(ALT | XK_q, XCF_Quarterspace);
    add_binding(XK_backslash, XCF_Special);
@@ -649,10 +649,14 @@ void default_keybindings()
    add_binding(XK_G, XCF_Pin_Global);
    add_binding(XK_I, XCF_Info_Label);
    add_binding(ALT | XK_w, XCF_Connectivity);
-   add_binding(ALT | XK_d, XCF_Sim);
-   add_binding(ALT | XK_a, XCF_SPICE);
-   add_binding(ALT | XK_f, XCF_SPICEflat);
-   add_binding(ALT | XK_p, XCF_PCB);
+
+/* These are for test purposes only.  Menu selection is	*/
+/* preferred.						*/
+
+/* add_binding(ALT | XK_d, XCF_Sim);		*/
+/* add_binding(ALT | XK_a, XCF_SPICE);		*/
+/* add_binding(ALT | XK_f, XCF_SPICEflat);	*/
+/* add_binding(ALT | XK_p, XCF_PCB);		*/
 #endif
 
 }
