@@ -1552,12 +1552,15 @@ void makepagebutton()
 
 void renamepage(short pagenumber)
 {
+   int page;
+   objinstptr thisinst = xobjs.pagelist[pagenumber]->pageinst;
+
 #ifdef TCL_WRAPPER
    char *pname, *plabel;
 
    if ((pagenumber >= 0) && (pagenumber < xobjs.pages - 1) &&
-	    (xobjs.pagelist[pagenumber]->pageinst != NULL)) {
-      plabel = xobjs.pagelist[pagenumber]->pageinst->thisobject->name;
+	    (thisinst != NULL)) {
+      plabel = thisinst->thisobject->name;
       pname = (char *)malloc(28 + strlen(plabel));
       sprintf(pname, "xcircuit::renamepage %d {%s}", pagenumber + 1, plabel);
       Tcl_Eval(xcinterp, pname);
@@ -1572,10 +1575,10 @@ void renamepage(short pagenumber)
    sprintf(bname, "Page %d", pagenumber + 1);
    button = XtNameToWidget(parent, bname);
 
-   if ((button != NULL) && (xobjs.pagelist[pagenumber]->pageinst != NULL)) {
-      if (xobjs.pagelist[pagenumber]->pageinst->thisobject->name != NULL)
+   if ((button != NULL) && (thisinst != NULL)) {
+      if (thisinst->thisobject->name != NULL)
          XtSetArg(wargs[0], XtNlabel,
-		xobjs.pagelist[pagenumber]->pageinst->thisobject->name);
+		thisinst->thisobject->name);
       else
          XtSetArg(wargs[0], XtNlabel, bname);
       XtSetValues(button, wargs, 1);
@@ -1583,6 +1586,36 @@ void renamepage(short pagenumber)
    else if (button == NULL)
       Fprintf(stderr, "Error:  No Button Widget named \"%9s\"\n", bname);
 #endif
+
+#ifdef SCHEMA
+   /* If the page had a master but now has a different	*/
+   /* name, disconnect the schematics.			*/
+
+   if (thisinst->thisobject->schemtype == SECONDARY) {
+      if (strcmp(thisinst->thisobject->name, thisinst->thisobject->symschem->name)) {
+	 thisinst->thisobject->symschem = NULL;
+	 thisinst->thisobject->schemtype = PRIMARY;
+      }
+      Wprintf("Page disconnected from master schematic.");
+   }
+
+   /* Conversely, if the page has the same name as another page, the	*/
+   /* schematics are considered connected.				*/
+
+   for (page = 0; page < xobjs.pages; page++) {
+      objinstptr pageinst;
+      if (page == pagenumber) continue;
+      pageinst = xobjs.pagelist[page]->pageinst;
+      if (pageinst && !strcmp(pageinst->thisobject->name,
+		thisinst->thisobject->name)) {
+	 thisinst->thisobject->symschem = pageinst->thisobject;
+	 thisinst->thisobject->schemtype = SECONDARY;
+         Wprintf("Page connected to master schematic.");
+	 break;
+      }
+   }
+#endif
+
 }
 
 /*--------------------------------------------------------------*/
