@@ -6,19 +6,23 @@
 /* from tclxcircuit.c */
 
 #ifdef TCL_WRAPPER
-
 extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
-
+extern Tcl_Obj *evaluate_raw(oparamptr);
+extern char *TCL_to_PS(char *);
 #endif
 
+extern char *evaluate_expr(oparamptr);
+
 /* from elements.c: */
 
+extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
 extern void objectdefaults(objinstptr, objectptr, int, int);
 extern void labeldefaults(labelptr, u_char, int, int);
+extern void poly_add_point(polyptr, XPoint *);
 extern void polydefaults(polyptr, int, int, int);
 extern void splinedefaults(splineptr, int, int);
 extern void arcdefaults(arcptr, int, int);
@@ -167,7 +171,7 @@ extern int lookdirectory(char *);
 
 /* from files.c: */
 
-extern void ridnewline(char *);
+extern char *ridnewline(char *);
 extern void free_single(genericptr *);
 extern void reset(objectptr, short);
 extern void pagereset(short);
@@ -179,6 +183,7 @@ extern short objcompare(objectptr, objectptr);
 extern float getpsscale(float, short);
 extern void dostcount(FILE *, short *, short);
 extern short printparams(FILE *, objinstptr, short);
+extern void printobjectparams(FILE *, objectptr);
 extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
 extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
 extern void varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
@@ -195,6 +200,7 @@ extern void startloadfile();
 extern void importfile();
 extern void loadfile(short);
 extern void readlabel(objectptr, char *, stringpart **);
+extern void readparams(objectptr, objinstptr, objectptr, char *);
 extern u_char *find_match(u_char *);
 extern char *advancetoken(char *);
 extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
@@ -249,6 +255,7 @@ extern void findsplinepos(splineptr, float, XPoint *, int *);
 extern void ffindsplinepos(splineptr, float, XfPoint *);
 extern float findsplinemin(splineptr, XPoint *);
 extern short closepoint(polyptr, XPoint *);
+extern void updateinstparam(objectptr);
 extern short checkbounds();
 extern void window_to_user(short, short, XPoint *);
 extern void user_to_window(XPoint, XPoint *);
@@ -474,9 +481,13 @@ extern Boolean dospecial(void);
 /* from netlist.c: */
 
 #ifdef SCHEMA
+extern Boolean RemoveFromNetlist(objectptr, genericptr);
+extern labelptr NetToLabel(int, objectptr);
+extern void NameToPosition(objinstptr, labelptr, XPoint *);
+extern void invalidate_netlist(objectptr);
+extern int updatenets(objinstptr);
 extern void createnets(objinstptr);
 extern void destroynets();
-extern void gennet(char *, char *);
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
 extern void gennetlist(objectptr, objinstptr);
@@ -514,19 +525,23 @@ extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
 extern void writehierarchy(objectptr, CalllistPtr, FILE *);
 extern void writenet(objectptr, char *, char *);
-extern void writepcb(objectptr, CalllistPtr, char *, char *);
-extern void outputpcb(objectptr, FILE *);
-extern void freepcb();
+extern void writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
+extern void outputpcb(struct Ptab *, FILE *);
+extern void freepcb(struct Ptab *);
+extern void freepolylist(NetlistPtr);
+extern void freelabellist(NetlistPtr);
+extern void freeports(CalllistPtr);
 extern void freenets(objectptr);
 extern void freetemplabels(objectptr);
 extern void freeglobals();
-extern int cleartraversed(objectptr, int);
+extern int cleartraversed(objectptr);
 extern int checkvalid(objectptr);
 extern void clearpins(objectptr);
 #endif
 
 /* from parameter.c: */ 
 
+extern char *find_indirect_param(objinstptr, char *);
 extern oparamptr match_param(objectptr, char *);
 extern oparamptr match_instance_param(objinstptr, char *);
 extern oparamptr find_param(objinstptr, char *);
@@ -538,6 +553,9 @@ extern void free_element_param(genericptr, eparamptr);
 extern oparamptr make_new_parameter(char *);
 extern eparamptr make_new_eparam(char *);
 
+extern void makeexprparam(objectptr, char *, char *, int);
+extern void makefloatparam(objectptr, char *, float);
+extern void makestringparam(objectptr, char *, stringpart *);
 extern void indicateparams(genericptr);
 extern void makenumericalp(genericptr *, u_int, char *);
 extern void noparmstrcpy(u_char *, u_char *);
@@ -610,7 +628,7 @@ extern int reset_gs();
 /* from schema.c: */
 
 extern objectptr NameToObject(char *, objinstptr *, Boolean);
-extern void callgennet(xcWidget, pointertype, caddr_t);
+extern void callwritenet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
 extern void startconnect(xcWidget, caddr_t, caddr_t);
 extern int connectivity(xcWidget, caddr_t, caddr_t);
