@@ -44,6 +44,25 @@ extern char _STR[150];
 /* Global value of distance between characters in the font catalog */
 short del;
 
+#ifndef TCL_WRAPPER
+
+/*----------------------------------------------------------------------*/
+/* Evaluation of expression types in strings (non-Tcl version---these	*/
+/* are PostScript expressions).						*/
+/*									*/
+/* For now, expressions are just copied as-is, without evaluation.	*/
+/* An allocated string is returned, and it is the responsibility of the	*/
+/* calling routine to free it.						*/
+/*----------------------------------------------------------------------*/
+
+char *evaluate_expr(oparamptr ops)
+{
+   if (ops->type != XC_EXPR) return NULL;
+   return strdup(ops->parameter.expr);
+}
+
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Determine if a label contains a parameter.				*/
 /*----------------------------------------------------------------------*/
@@ -327,8 +346,10 @@ stringpart *linkstring(objinstptr localinst, stringpart *strstart)
       /* Promote numerical type to string */
       if (ops->type == XC_INT)
 	 sprintf(promote->data.string, "%12d", ops->parameter.ivalue);
+      else if (ops->type == XC_FLOAT)
+	 sprintf(promote->data.string, "%g", (double)(ops->parameter.fvalue));
       else
-	 sprintf(promote->data.string, "%f", ops->parameter.fvalue);
+	 promote->data.string = evaluate_expr(ops);
       nextptr = promote;
    }
    else
@@ -493,7 +514,8 @@ char *stringprint(stringpart *strtop, objinstptr localinst)
 
 /*----------------------------------------------------------------------*/
 /*  textprint() excludes text controls, resulting in a string 		*/
-/*  appropriate for netlist information.				*/
+/*  appropriate for netlist information, or for promoting a string	*/
+/*  parameter to a numeric type.					*/
 /*----------------------------------------------------------------------*/
 
 char *textprint(stringpart *strtop, objinstptr localinst)
@@ -723,7 +745,7 @@ stringpart *stringcopy(stringpart *string)
       topptr = newpart;
 
       newpart->type = strptr->type;
-      if (strptr->type == TEXT_STRING) {
+      if ((strptr->type == TEXT_STRING) || (strptr->type == PARAM_START)) {
 	 newpart->data.string = (char *)malloc(1 + strlen(strptr->data.string));
 	 strcpy(newpart->data.string, strptr->data.string);
       }
@@ -770,6 +792,7 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
    stringpart *strptr, *newpart, *curend = NULL, *rettop, *curtop, *savend;
    char *key = NULL;
    oparamptr pparam;
+   Boolean need_free;
 
    for (strptr = string; strptr != NULL; strptr = strptr->nextpart) {
 
@@ -785,10 +808,13 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
 	    key = curend->data.string;
 	    curtop = newpart;
 	    savend = curend;
+	    need_free = False;
          }
          else if (curend->type == PARAM_END) {
 	    curend->nextpart = NULL;
 	    savend->nextpart = newpart;
+	    if (need_free) freelabel(curtop);
+	    need_free = False;
          }
       }
       curend = newpart;
@@ -802,18 +828,42 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
 	    newpart->data.string = NULL;
       }
       else if (strptr->type == PARAM_END) {
-	 /* If thisinst is NULL, then use topobject (top level object) */
-
 	 if (key != NULL) {
 	    pparam = find_param(thisinst, key);
 	    if (pparam == NULL) {
 	       Fprintf(stderr, "Error:  Bad parameter %s encountered!\n", key);
 	    }
-	    else  {
+	    else if (pparam->type == XC_STRING) {
 	       freelabel(pparam->parameter.string);
 	       pparam->parameter.string = curtop;
 	       key = NULL;
 	    }
+	    else {
+	       float fval;
+	       int ival;
+	       char *tmpstr = textprint(curtop, thisinst);
+
+	       /* Promote string types into the type of the parameter */
+	       switch (pparam->type) {
+		  case XC_INT:
+		     if (sscanf(tmpstr, "%d", &ival) == 1)
+		        pparam->parameter.ivalue = ival;
+		     free(tmpstr);
+		     break;
+		  case XC_FLOAT:
+		     if (sscanf(tmpstr, "%g", &fval) == 1)
+		        pparam->parameter.fvalue = fval;
+		     break;
+		  case XC_EXPR:
+		     /* Expression results are derived and cannot be	*/
+		     /* changed except by changing the expression	*/
+		     /* itself.						*/
+		     break;
+	       }
+	       free(tmpstr);
+	       need_free = True;
+	       key = NULL;
+	    }
 	 }
          else {
 	    Fprintf(stderr, "Error:  Bad parameter in stringcopyback()\n");
@@ -824,8 +874,10 @@ stringpart *stringcopyback(stringpart *string, objinstptr thisinst)
    }
 
    /* tie up loose ends, if necessary */
-   if ((curend != NULL) && (curend->type == PARAM_END))
+   if ((curend != NULL) && (curend->type == PARAM_END)) {
       savend->nextpart = NULL;
+      if (need_free) freelabel(curtop);
+   }
 
    return rettop;
 }
