@@ -343,10 +343,11 @@ ULPARAM_MODE, UIPARAM_MODE
 
 #ifdef SCHEMA
 
-#define SCHEMATIC 0		/* Schematic on page */
-#define TRIVIAL 1		/* Symbol as non-schematic element */
-#define SYMBOL 2		/* Symbol associated with a schematic */
-#define FUNDAMENTAL 3		/* Standalone symbol */
+#define PRIMARY 0		/* Primary (master) schematic page */
+#define SECONDARY 1		/* Secondary (slave) schematic page */
+#define TRIVIAL 2		/* Symbol as non-schematic element */
+#define SYMBOL 3		/* Symbol associated with a schematic */
+#define FUNDAMENTAL 4		/* Standalone symbol */
 
 #define LOCAL 1
 #define GLOBAL 2
@@ -415,11 +416,13 @@ typedef XfPoint* fpointlist;
 #define PATH	32
 #define SEL_ANY	63  /* for selection mechanism only */
 
+#define REMOVE_TAG 64  /* add this value to objects to be removed */
+
 /*----------------------------------------------------------------------*/
 /* Allowed parameterization types					*/
 /*----------------------------------------------------------------------*/
 
-#define P_POSITION	0	/* mode only, not a real parameter */
+#define P_NUMERIC	0	/* uncommitted numeric parameter */
 #define P_SUBSTRING	1
 #define P_POSITION_X	2
 #define P_POSITION_Y	3
@@ -433,6 +436,8 @@ typedef XfPoint* fpointlist;
 #define P_SCALE		11
 #define P_LINEWIDTH	12
 #define P_COLOR		13
+#define P_EXPRESSION	14
+#define P_POSITION	15	/* mode only, not a real parameter */
 
 /*----------------------------------------------------------------------*/
 /* Labels are constructed of strings and executables 			*/
@@ -461,7 +466,7 @@ typedef struct _stringpart {
 /* (Add types as necessary)						*/
 /*----------------------------------------------------------------------*/
 
-enum paramtypes {XC_INT = 0, XC_FLOAT, XC_STRING};
+enum paramtypes {XC_INT = 0, XC_FLOAT, XC_STRING, XC_EXPR};
 
 /* Object parameters: general key:value parameter model */
 /* Note that this really should be a hash table, not a linked list. . . */
@@ -473,7 +478,8 @@ typedef struct _oparam {
    u_char	type;		/* type is from paramtypes list above */
    u_char	which;		/* what the parameter represents (P_*) */
    union {
-      stringpart *string;
+      stringpart *string;	/* xcircuit label type */
+      char	 *expr;		/* TCL (postscript) expression */
       int	  ivalue;	/* also covers type short int by typecasting */
       float	  fvalue;
    } parameter;			/* default or substitution value */
@@ -658,8 +664,9 @@ typedef struct {
 typedef struct _Polylist *PolylistPtr;
 typedef struct _Polylist
 {
+   objectptr cschem;	/* Schematic containing the polygon */
    polyptr poly;
-   PolylistPtr next;
+   PolylistPtr next;	/* Next polygon in the linked list */
 } Polylist;
 
 /* Linked label list */
@@ -667,6 +674,7 @@ typedef struct _Polylist
 typedef struct _Labellist *LabellistPtr;
 typedef struct _Labellist
 {
+   objectptr cschem;	/* Schematic containing the label */
    labelptr label;
    LabellistPtr next;
 } Labellist;
@@ -699,8 +707,9 @@ typedef struct _Portlist
 typedef struct _Calllist *CalllistPtr;
 typedef struct _Calllist
 {
-   objectptr   callobj;
-   objinstptr  callinst;
+   objectptr   cschem;		/* Schematic page containing the instance */
+   objinstptr  callinst;	/* Instance called */
+   objectptr   callobj;		/* Object of instance called */
    int         devindex;	/* if non-zero, index of device in netlist */
    PortlistPtr ports;
    CalllistPtr next;
@@ -720,6 +729,7 @@ struct Pstr {
 };
 
 struct Ptab {
+   objectptr cschem;
    struct Pnet *nets;
    struct Pstr *pins;
    struct Ptab *next;
@@ -756,7 +766,6 @@ typedef struct _xcobject {
    Highlight	highlight;	/* net to be highlighted on redraw */
    u_char	schemtype;
    objectptr	symschem;	/* schematic page support */
-
    char		*devname;	/* if non-null, name of device in netlist */
    Boolean	valid;		/* Is current netlist valid? */
    Boolean	traversed;	/* Flag to indicate object was processed */
@@ -898,7 +907,7 @@ enum {DIRECTORY = 0, MATCH, NONMATCH};	/* file types */
 typedef struct {
 #ifdef SCHEMA
    /* schematic layout colors */
-   Pixel	globalcolor, localcolor, infocolor;
+   Pixel	globalcolor, localcolor, infocolor, ratsnestcolor;
 #endif
 
    /* non-schematic layout color(s) */
@@ -1005,11 +1014,11 @@ enum {
    XCF_ENDDATA = -2, XCF_SPACER,
    XCF_Page, XCF_Justify, XCF_Superscript, XCF_Subscript, XCF_Normalscript,
    XCF_Nextfont, XCF_Boldfont, XCF_Italicfont, XCF_Normalfont, XCF_Underline,
-   XCF_Overline, XCF_ISO_Encoding, XCF_Return, XCF_Halfspace, XCF_Quarterspace,
+   XCF_Overline, XCF_ISO_Encoding, XCF_Halfspace, XCF_Quarterspace,
    XCF_Special, XCF_TabStop, XCF_TabForward, XCF_TabBackward,
    XCF_Text_Return, XCF_Text_Delete, XCF_Text_Right, XCF_Text_Left,
    XCF_Text_Up, XCF_Text_Down, XCF_Text_Split,
-   XCF_Text_Home, XCF_Text_End, XCF_Return_Char, XCF_Parameter,
+   XCF_Text_Home, XCF_Text_End, XCF_Linebreak, XCF_Parameter,
    XCF_Edit_Param,XCF_Edit_Break, XCF_Edit_Delete, XCF_Edit_Insert,
    XCF_Edit_Append, XCF_Edit_Next, XCF_Attach,
    XCF_Next_Library, XCF_Library_Directory,
